pub enum NextHook {
Break,
PrevInstalledHook,
}Expand description
Specifies whether to stop at currently executed scoped hook or continue with other options
Variants
Break
Don’t call anything after hook which returned this value
PrevInstalledHook
Call hook which precedes scoped hooks; usually that’s default hook