Module panic

Module panic 

Panic capture types and functions, including some with finer tuned functionality

Structs

CatchPanicConfig
Options for catch_panic_with_config
OwnedLocation
Simple structure which mirrors std::panic::Location, although owns file name and is freely movable around
Panic
Panic info gathered as one record

Enums

BacktraceStyle
Backtrace display style
CaptureBacktrace
Determines how to capture backtrace when catching panic

Functions

catch_panic
Runs provided closure and captures panic if one happens, along with its backtrace
catch_panic_with_config
Runs provided closure and captures panic if one happens